collectiondbf
=======
Collection Downloads from BlackFynn 

A tool for downloading a collection of files from Blackfynn

Usage
-------
```
pip install collectiondbf
python -m collectiondbf <api-key> <api-secret> <collection:ID>
```

If you cannot find the collection ID for the folder you wish to download, check for it in the url like so:

![collectionID](https://user-images.githubusercontent.com/37255664/64832679-fe039c80-d62e-11e9-96db-38a54cbd6c55.jpg)


